@@ -2,7 +2,7 @@
 from __future__ import generators
 import sys
 from logging import getLogger, StreamHandler, INFO
-from metamake._path import loggable_path as path
+from metamake._path import LoggablePath as path
 from metamake._bootstrap import serialize_metamake_to_makefile
 from metamake._flags import Flag
 from metamake._dependencies import Dependency
@@ -24,7 +24,7 @@ __all__ = [
     "run_default_task",
 ]
 
-__version__ = "1.1.6"
+__version__ = "1.1.7"
 
 _DEFAULT_STDERR_LOGS = ["metamake.filesystem", "metamake.shell"]
 _all_tasks = {}
