@@ -39,7 +39,7 @@ except ImportError:
     import md5
 
 __version__ = '2.2'
-__all__ = ['path', 'loggable_path']
+__all__ = ['path', 'LoggablePath']
 
 # Platform-specific support for path.owner
 if os.name == 'nt':
@@ -977,8 +977,10 @@ class path(_base):
 
 
 ######################################################################
+PathObject = path
 
-class loggable_path(path):
+
+class LoggablePath(PathObject):
     """wraps the path class with logging for interesting methods"""
     
     def _log(self, name):
@@ -989,169 +991,170 @@ class loggable_path(path):
     
     def listdir(self, pattern = None):
         self._log("listdir{pattern=%(pattern)s}" % locals())
-        return path.listdir(self, pattern)
+        return PathObject.listdir(self, pattern)
     
     def dirs(self, pattern = None):
         self._log("dirs{pattern=%(pattern)s}" % locals())
-        return path.dirs(self, pattern)
+        return PathObject.dirs(self, pattern)
     
     def files(self, pattern = None):
         self._log("files{pattern=%(pattern)s}" % locals())
-        return path.files(self, pattern)
+        return PathObject.files(self, pattern)
     
     def walk(self, pattern = None, errors = 'strict'):
         self._log("walk{pattern=%(pattern)s, errors=%(errors)s}" % locals())
-        return path.walk(self, pattern, errors)
+        return PathObject.walk(self, pattern, errors)
     
     def walkdirs(self, pattern = None, errors = 'strict'):
         self._log("walkdirs{pattern=%(pattern)s, errors=%(errors)s}" % locals())
-        return path.walkdirs(self, pattern, errors)
+        return PathObject.walkdirs(self, pattern, errors)
     
     def walkfiles(self, pattern = None, errors = 'strict'):
         self._log("walkfiles{pattern=%(pattern)s, errors=%(errors)s}" % locals())
-        return path.walkfiles(self, pattern, errors)
+        return PathObject.walkfiles(self, pattern, errors)
     
     def fnmatch(self, pattern = None):
         self._log("fnmatch{pattern=%(pattern)s}" % locals())
-        return path.fnmatch(self, pattern)
+        return PathObject.fnmatch(self, pattern)
     
     def glob(self, pattern = None):
         self._log("glob{pattern=%(pattern)s}" % locals())
-        return path.glob(self, pattern)
+        return PathObject.glob(self, pattern)
     
     def open(self, mode = 'r'):
         self._log("open{mode=%(mode)s}" % locals())
-        return path.open(self, mode)
+        return PathObject.open(self, mode)
     
     def write_bytes(self, bytes, append = False):
         self._log("write_bytes{append=%(append)s}" % locals())
-        return path.write_bytes(self, bytes, append)
+        return PathObject.write_bytes(self, bytes, append)
     
     def write_text(self, text, encoding=None, errors='strict', linesep=os.linesep, append=False):
         self._log("write_text{errors=%(errors)s, append=%(append)s}" % locals())
-        return path.write_text(self, text, encoding, errors, linesep, append)
+        return PathObject.write_text(self, text, encoding, errors, linesep, append)
 
     def write_lines(self, lines, encoding=None, errors='strict', linesep=os.linesep, append=False):
         self._log("write_lines{errors=%(errors)s, append=%(append)s}" % locals())
-        return path.write_lines(self, lines, encoding, errors, linesep, append)
+        return PathObject.write_lines(self, lines, encoding, errors, linesep, append)
 
     def read_md5(self):
         self._log("read_md5")
-        return path.rmtree(self)
+        return PathObject.rmtree(self)
     
     def exists(self):
         self._log("exists?")
-        return path.exists(self)
+        return PathObject.exists(self)
     
     def isdir(self):
         self._log("isdir?")
-        return path.isdir(self)
+        return PathObject.isdir(self)
     
     def isfile(self):
         self._log("isfile?")
-        return path.isfile(self)
+        return PathObject.isfile(self)
     
     def islink(self):
         self._log("islink?")
-        return path.islink(self)
+        return PathObject.islink(self)
     
     def ismount(self):
         self._log("ismount?")
-        return path.ismount(self)
+        return PathObject.ismount(self)
     
     def samefile(self):
         self._log("samefile?")
-        return path.samefile(self)
+        return PathObject.samefile(self)
     
     def access(self, mode):
         self._log("access?{mode=%(mode)s}" % locals())
-        return path.access(self, mode)
+        return PathObject.access(self, mode)
     
     def chmod(self, mode):
         self._log("chmod{mode=%(mode)s}" % locals())
-        return path.chmod(self, mode)
+        return PathObject.chmod(self, mode)
     
     def chown(self, uid, gid):
         self._log("chown{uid=%(uid)s, gid=%(gid)s}" % locals())
-        return path.chown(self, uid, gid)
+        return PathObject.chown(self, uid, gid)
 
     def rename(self, new):
         self._log("rename{new=%(new)s}" % locals())
-        return path.rename(self, new)
+        return PathObject.rename(self, new)
 
     def renames(self, new):
         self._log("renames{new=%(new)s}" % locals())
-        return path.renames(self, new)
+        return PathObject.renames(self, new)
 
     def mkdir(self, mode=0777):
         self._log("mkdir{mode=%(mode)s}" % locals())
-        return path.mkdir(self, mode)
+        return PathObject.mkdir(self, mode)
 
     def makedirs(self, mode=0777):
         self._log("makedirs{mode=%(mode)s}" % locals())
-        return path.makedirs(self, mode)
+        return PathObject.makedirs(self, mode)
 
     def rmdir(self):
         self._log("rmdir")
-        return path.rmdir(self)
+        return PathObject.rmdir(self)
 
     def removedirs(self):
         os.removedirs(self)
         
     def touch(self):
         self._log("touch")
-        return path.touch(self)
+        return PathObject.touch(self)
     
     def remove(self):
         self._log("remove")
-        return path.remove(self)
+        return PathObject.remove(self)
     
     def unlink(self):
         self._log("unlink")
-        return path.unlink(self)
+        return PathObject.unlink(self)
     
     def link(self, newpath):
         self._log("link{newpath=%(newpath)s}" % locals())
-        return path.link(self, newpath)
+        return PathObject.link(self, newpath)
     
     def symlink(self, newlink):
         self._log("symlink{newlink=%(newlink)s}" % locals())
-        return path.symlink(self, newlink)
+        return PathObject.symlink(self, newlink)
         
     def copyfile(self, dst):
         self._log("copyfile{dst=%(dst)s}" % locals())
-        return path.copyfile(self, dst)
+        return PathObject.copyfile(self, dst)
         
     def copymode(self, dst):
         self._log("copymode{dst=%(dst)s}" % locals())
-        return path.copymode(self, dst)
+        return PathObject.copymode(self, dst)
         
     def copystat(self, dst):
         self._log("copystat{dst=%(dst)s}" % locals())
-        return path.copystat(self, dst)
+        return PathObject.copystat(self, dst)
         
     def copy(self, dst):
         self._log("copy{dst=%(dst)s}" % locals())
-        return path.copy(self, dst)
+        return PathObject.copy(self, dst)
         
     def copy2(self, dst):
         self._log("copy2{dst=%(dst)s}" % locals())
-        return path.copy2(self, dst)
+        return PathObject.copy2(self, dst)
         
     def copytree(self, dst, symlinks=None):
         self._log("copytree{dst=%(dst)s, symlinks=%(symlinks)s}" % locals())
-        return path.copytree(self, dst, symlinks)
+        return PathObject.copytree(self, dst, symlinks)
         
     def move(self, dst):
         self._log("move{dst=%(dst)s}" % locals())
-        return path.move(self, dst)
+        return PathObject.move(self, dst)
         
     def rmtree(self, ignore_errors=None, onerror=None):
         self._log("rmtree")
-        return path.rmtree(self, ignore_errors, onerror)
+        return PathObject.rmtree(self, ignore_errors, onerror)
     
     def __init__(self, path):
-        super(loggable_path, self).__init__(path)
+        # apparently, PathObject has no __init__
+        # PathObject.__init__(self, path)
         # set up our logging
         self.__logger = getLogger("metamake.filesystem")
         
